==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/GitHubOptions.java <==
package io.github.cdklabs.projen.github;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.761Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.GitHubOptions")
@software.amazon.jsii.Jsii.Proxy(GitHubOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface GitHubOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Whether mergify should be enabled on this repository or not.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getMergify() {
        return null;
    }

    /**
     * (experimental) Options for Mergify.
     * <p>
     * Default: - default options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.MergifyOptions getMergifyOptions() {
        return null;
    }

    /**
     * (experimental) Add a workflow that performs basic checks for pull requests, like validating that PRs follow Conventional Commits.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getPullRequestLint() {
        return null;
    }

    /**
     * (experimental) Options for configuring a pull request linter.
     * <p>
     * Default: - see defaults in `PullRequestLintOptions`
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.PullRequestLintOptions getPullRequestLintOptions() {
        return null;
    }

    /**
     * (experimental) Enables GitHub workflows.
     * <p>
     * If this is set to <code>false</code>, workflows will not be created.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getWorkflows() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link GitHubOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GitHubOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<GitHubOptions> {
        java.lang.Boolean mergify;
        io.github.cdklabs.projen.github.MergifyOptions mergifyOptions;
        java.lang.Boolean pullRequestLint;
        io.github.cdklabs.projen.github.PullRequestLintOptions pullRequestLintOptions;
        java.lang.Boolean workflows;

        /**
         * Sets the value of {@link GitHubOptions#getMergify}
         * @param mergify Whether mergify should be enabled on this repository or not.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder mergify(java.lang.Boolean mergify) {
            this.mergify = mergify;
            return this;
        }

        /**
         * Sets the value of {@link GitHubOptions#getMergifyOptions}
         * @param mergifyOptions Options for Mergify.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder mergifyOptions(io.github.cdklabs.projen.github.MergifyOptions mergifyOptions) {
            this.mergifyOptions = mergifyOptions;
            return this;
        }

        /**
         * Sets the value of {@link GitHubOptions#getPullRequestLint}
         * @param pullRequestLint Add a workflow that performs basic checks for pull requests, like validating that PRs follow Conventional Commits.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pullRequestLint(java.lang.Boolean pullRequestLint) {
            this.pullRequestLint = pullRequestLint;
            return this;
        }

        /**
         * Sets the value of {@link GitHubOptions#getPullRequestLintOptions}
         * @param pullRequestLintOptions Options for configuring a pull request linter.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pullRequestLintOptions(io.github.cdklabs.projen.github.PullRequestLintOptions pullRequestLintOptions) {
            this.pullRequestLintOptions = pullRequestLintOptions;
            return this;
        }

        /**
         * Sets the value of {@link GitHubOptions#getWorkflows}
         * @param workflows Enables GitHub workflows.
         *                  If this is set to <code>false</code>, workflows will not be created.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder workflows(java.lang.Boolean workflows) {
            this.workflows = workflows;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GitHubOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public GitHubOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GitHubOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GitHubOptions {
        private final java.lang.Boolean mergify;
        private final io.github.cdklabs.projen.github.MergifyOptions mergifyOptions;
        private final java.lang.Boolean pullRequestLint;
        private final io.github.cdklabs.projen.github.PullRequestLintOptions pullRequestLintOptions;
        private final java.lang.Boolean workflows;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.mergify = software.amazon.jsii.Kernel.get(this, "mergify", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.mergifyOptions = software.amazon.jsii.Kernel.get(this, "mergifyOptions", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.MergifyOptions.class));
            this.pullRequestLint = software.amazon.jsii.Kernel.get(this, "pullRequestLint", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.pullRequestLintOptions = software.amazon.jsii.Kernel.get(this, "pullRequestLintOptions", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.PullRequestLintOptions.class));
            this.workflows = software.amazon.jsii.Kernel.get(this, "workflows", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.mergify = builder.mergify;
            this.mergifyOptions = builder.mergifyOptions;
            this.pullRequestLint = builder.pullRequestLint;
            this.pullRequestLintOptions = builder.pullRequestLintOptions;
            this.workflows = builder.workflows;
        }

        @Override
        public final java.lang.Boolean getMergify() {
            return this.mergify;
        }

        @Override
        public final io.github.cdklabs.projen.github.MergifyOptions getMergifyOptions() {
            return this.mergifyOptions;
        }

        @Override
        public final java.lang.Boolean getPullRequestLint() {
            return this.pullRequestLint;
        }

        @Override
        public final io.github.cdklabs.projen.github.PullRequestLintOptions getPullRequestLintOptions() {
            return this.pullRequestLintOptions;
        }

        @Override
        public final java.lang.Boolean getWorkflows() {
            return this.workflows;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getMergify() != null) {
                data.set("mergify", om.valueToTree(this.getMergify()));
            }
            if (this.getMergifyOptions() != null) {
                data.set("mergifyOptions", om.valueToTree(this.getMergifyOptions()));
            }
            if (this.getPullRequestLint() != null) {
                data.set("pullRequestLint", om.valueToTree(this.getPullRequestLint()));
            }
            if (this.getPullRequestLintOptions() != null) {
                data.set("pullRequestLintOptions", om.valueToTree(this.getPullRequestLintOptions()));
            }
            if (this.getWorkflows() != null) {
                data.set("workflows", om.valueToTree(this.getWorkflows()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.GitHubOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GitHubOptions.Jsii$Proxy that = (GitHubOptions.Jsii$Proxy) o;

            if (this.mergify != null ? !this.mergify.equals(that.mergify) : that.mergify != null) return false;
            if (this.mergifyOptions != null ? !this.mergifyOptions.equals(that.mergifyOptions) : that.mergifyOptions != null) return false;
            if (this.pullRequestLint != null ? !this.pullRequestLint.equals(that.pullRequestLint) : that.pullRequestLint != null) return false;
            if (this.pullRequestLintOptions != null ? !this.pullRequestLintOptions.equals(that.pullRequestLintOptions) : that.pullRequestLintOptions != null) return false;
            return this.workflows != null ? this.workflows.equals(that.workflows) : that.workflows == null;
        }

        @Override
        public final int hashCode() {
            int result = this.mergify != null ? this.mergify.hashCode() : 0;
            result = 31 * result + (this.mergifyOptions != null ? this.mergifyOptions.hashCode() : 0);
            result = 31 * result + (this.pullRequestLint != null ? this.pullRequestLint.hashCode() : 0);
            result = 31 * result + (this.pullRequestLintOptions != null ? this.pullRequestLintOptions.hashCode() : 0);
            result = 31 * result + (this.workflows != null ? this.workflows.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/GitHubOptions.java <==
package io.github.cdklabs.projen.github;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.419Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.GitHubOptions")
@software.amazon.jsii.Jsii.Proxy(GitHubOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface GitHubOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Download files in LFS in workflows.
     * <p>
     * Default: true if the associated project has `lfsPatterns`, `false` otherwise
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getDownloadLfs() {
        return null;
    }

    /**
     * (experimental) Whether mergify should be enabled on this repository or not.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getMergify() {
        return null;
    }

    /**
     * (experimental) Options for Mergify.
     * <p>
     * Default: - default options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.MergifyOptions getMergifyOptions() {
        return null;
    }

    /**
     * (experimental) Choose a method of providing GitHub API access for projen workflows.
     * <p>
     * Default: - use a personal access token named PROJEN_GITHUB_TOKEN
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.GithubCredentials getProjenCredentials() {
        return null;
    }

    /**
     * (deprecated) The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows.
     * <p>
     * This token needs to have the <code>repo</code>, <code>workflows</code>
     * and <code>packages</code> scope.
     * <p>
     * Default: "PROJEN_GITHUB_TOKEN"
     * <p>
     * @deprecated <ul>
     * <li>use <code>projenCredentials</code></li>
     * </ul>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.String getProjenTokenSecret() {
        return null;
    }

    /**
     * (experimental) Add a workflow that performs basic checks for pull requests, like validating that PRs follow Conventional Commits.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getPullRequestLint() {
        return null;
    }

    /**
     * (experimental) Options for configuring a pull request linter.
     * <p>
     * Default: - see defaults in `PullRequestLintOptions`
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.PullRequestLintOptions getPullRequestLintOptions() {
        return null;
    }

    /**
     * (experimental) Enables GitHub workflows.
     * <p>
     * If this is set to <code>false</code>, workflows will not be created.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getWorkflows() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link GitHubOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GitHubOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<GitHubOptions> {
        java.lang.Boolean downloadLfs;
        java.lang.Boolean mergify;
        io.github.cdklabs.projen.github.MergifyOptions mergifyOptions;
        io.github.cdklabs.projen.github.GithubCredentials projenCredentials;
        java.lang.String projenTokenSecret;
        java.lang.Boolean pullRequestLint;
        io.github.cdklabs.projen.github.PullRequestLintOptions pullRequestLintOptions;
        java.lang.Boolean workflows;

        /**
         * Sets the value of {@link GitHubOptions#getDownloadLfs}
         * @param downloadLfs Download files in LFS in workflows.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder downloadLfs(java.lang.Boolean downloadLfs) {
            this.downloadLfs = downloadLfs;
            return this;
        }

        /**
         * Sets the value of {@link GitHubOptions#getMergify}
         * @param mergify Whether mergify should be enabled on this repository or not.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder mergify(java.lang.Boolean mergify) {
            this.mergify = mergify;
            return this;
        }

        /**
         * Sets the value of {@link GitHubOptions#getMergifyOptions}
         * @param mergifyOptions Options for Mergify.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder mergifyOptions(io.github.cdklabs.projen.github.MergifyOptions mergifyOptions) {
            this.mergifyOptions = mergifyOptions;
            return this;
        }

        /**
         * Sets the value of {@link GitHubOptions#getProjenCredentials}
         * @param projenCredentials Choose a method of providing GitHub API access for projen workflows.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder projenCredentials(io.github.cdklabs.projen.github.GithubCredentials projenCredentials) {
            this.projenCredentials = projenCredentials;
            return this;
        }

        /**
         * Sets the value of {@link GitHubOptions#getProjenTokenSecret}
         * @param projenTokenSecret The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows.
         *                          This token needs to have the <code>repo</code>, <code>workflows</code>
         *                          and <code>packages</code> scope.
         * @return {@code this}
         * @deprecated - use `projenCredentials`
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder projenTokenSecret(java.lang.String projenTokenSecret) {
            this.projenTokenSecret = projenTokenSecret;
            return this;
        }

        /**
         * Sets the value of {@link GitHubOptions#getPullRequestLint}
         * @param pullRequestLint Add a workflow that performs basic checks for pull requests, like validating that PRs follow Conventional Commits.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pullRequestLint(java.lang.Boolean pullRequestLint) {
            this.pullRequestLint = pullRequestLint;
            return this;
        }

        /**
         * Sets the value of {@link GitHubOptions#getPullRequestLintOptions}
         * @param pullRequestLintOptions Options for configuring a pull request linter.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pullRequestLintOptions(io.github.cdklabs.projen.github.PullRequestLintOptions pullRequestLintOptions) {
            this.pullRequestLintOptions = pullRequestLintOptions;
            return this;
        }

        /**
         * Sets the value of {@link GitHubOptions#getWorkflows}
         * @param workflows Enables GitHub workflows.
         *                  If this is set to <code>false</code>, workflows will not be created.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder workflows(java.lang.Boolean workflows) {
            this.workflows = workflows;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GitHubOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public GitHubOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GitHubOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GitHubOptions {
        private final java.lang.Boolean downloadLfs;
        private final java.lang.Boolean mergify;
        private final io.github.cdklabs.projen.github.MergifyOptions mergifyOptions;
        private final io.github.cdklabs.projen.github.GithubCredentials projenCredentials;
        private final java.lang.String projenTokenSecret;
        private final java.lang.Boolean pullRequestLint;
        private final io.github.cdklabs.projen.github.PullRequestLintOptions pullRequestLintOptions;
        private final java.lang.Boolean workflows;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.downloadLfs = software.amazon.jsii.Kernel.get(this, "downloadLfs", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.mergify = software.amazon.jsii.Kernel.get(this, "mergify", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.mergifyOptions = software.amazon.jsii.Kernel.get(this, "mergifyOptions", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.MergifyOptions.class));
            this.projenCredentials = software.amazon.jsii.Kernel.get(this, "projenCredentials", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.GithubCredentials.class));
            this.projenTokenSecret = software.amazon.jsii.Kernel.get(this, "projenTokenSecret", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.pullRequestLint = software.amazon.jsii.Kernel.get(this, "pullRequestLint", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.pullRequestLintOptions = software.amazon.jsii.Kernel.get(this, "pullRequestLintOptions", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.PullRequestLintOptions.class));
            this.workflows = software.amazon.jsii.Kernel.get(this, "workflows", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.downloadLfs = builder.downloadLfs;
            this.mergify = builder.mergify;
            this.mergifyOptions = builder.mergifyOptions;
            this.projenCredentials = builder.projenCredentials;
            this.projenTokenSecret = builder.projenTokenSecret;
            this.pullRequestLint = builder.pullRequestLint;
            this.pullRequestLintOptions = builder.pullRequestLintOptions;
            this.workflows = builder.workflows;
        }

        @Override
        public final java.lang.Boolean getDownloadLfs() {
            return this.downloadLfs;
        }

        @Override
        public final java.lang.Boolean getMergify() {
            return this.mergify;
        }

        @Override
        public final io.github.cdklabs.projen.github.MergifyOptions getMergifyOptions() {
            return this.mergifyOptions;
        }

        @Override
        public final io.github.cdklabs.projen.github.GithubCredentials getProjenCredentials() {
            return this.projenCredentials;
        }

        @Override
        public final java.lang.String getProjenTokenSecret() {
            return this.projenTokenSecret;
        }

        @Override
        public final java.lang.Boolean getPullRequestLint() {
            return this.pullRequestLint;
        }

        @Override
        public final io.github.cdklabs.projen.github.PullRequestLintOptions getPullRequestLintOptions() {
            return this.pullRequestLintOptions;
        }

        @Override
        public final java.lang.Boolean getWorkflows() {
            return this.workflows;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDownloadLfs() != null) {
                data.set("downloadLfs", om.valueToTree(this.getDownloadLfs()));
            }
            if (this.getMergify() != null) {
                data.set("mergify", om.valueToTree(this.getMergify()));
            }
            if (this.getMergifyOptions() != null) {
                data.set("mergifyOptions", om.valueToTree(this.getMergifyOptions()));
            }
            if (this.getProjenCredentials() != null) {
                data.set("projenCredentials", om.valueToTree(this.getProjenCredentials()));
            }
            if (this.getProjenTokenSecret() != null) {
                data.set("projenTokenSecret", om.valueToTree(this.getProjenTokenSecret()));
            }
            if (this.getPullRequestLint() != null) {
                data.set("pullRequestLint", om.valueToTree(this.getPullRequestLint()));
            }
            if (this.getPullRequestLintOptions() != null) {
                data.set("pullRequestLintOptions", om.valueToTree(this.getPullRequestLintOptions()));
            }
            if (this.getWorkflows() != null) {
                data.set("workflows", om.valueToTree(this.getWorkflows()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.GitHubOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GitHubOptions.Jsii$Proxy that = (GitHubOptions.Jsii$Proxy) o;

            if (this.downloadLfs != null ? !this.downloadLfs.equals(that.downloadLfs) : that.downloadLfs != null) return false;
            if (this.mergify != null ? !this.mergify.equals(that.mergify) : that.mergify != null) return false;
            if (this.mergifyOptions != null ? !this.mergifyOptions.equals(that.mergifyOptions) : that.mergifyOptions != null) return false;
            if (this.projenCredentials != null ? !this.projenCredentials.equals(that.projenCredentials) : that.projenCredentials != null) return false;
            if (this.projenTokenSecret != null ? !this.projenTokenSecret.equals(that.projenTokenSecret) : that.projenTokenSecret != null) return false;
            if (this.pullRequestLint != null ? !this.pullRequestLint.equals(that.pullRequestLint) : that.pullRequestLint != null) return false;
            if (this.pullRequestLintOptions != null ? !this.pullRequestLintOptions.equals(that.pullRequestLintOptions) : that.pullRequestLintOptions != null) return false;
            return this.workflows != null ? this.workflows.equals(that.workflows) : that.workflows == null;
        }

        @Override
        public final int hashCode() {
            int result = this.downloadLfs != null ? this.downloadLfs.hashCode() : 0;
            result = 31 * result + (this.mergify != null ? this.mergify.hashCode() : 0);
            result = 31 * result + (this.mergifyOptions != null ? this.mergifyOptions.hashCode() : 0);
            result = 31 * result + (this.projenCredentials != null ? this.projenCredentials.hashCode() : 0);
            result = 31 * result + (this.projenTokenSecret != null ? this.projenTokenSecret.hashCode() : 0);
            result = 31 * result + (this.pullRequestLint != null ? this.pullRequestLint.hashCode() : 0);
            result = 31 * result + (this.pullRequestLintOptions != null ? this.pullRequestLintOptions.hashCode() : 0);
            result = 31 * result + (this.workflows != null ? this.workflows.hashCode() : 0);
            return result;
        }
    }
}
